Index: src/roadveh_cmd.cpp
===================================================================
--- src/roadveh_cmd.cpp (revision 27189)
+++ src/roadveh_cmd.cpp (working copy)
@@ -824,8 +824,9 @@
if (v->state >= RVSB_IN_ROAD_STOP || !IsStraightRoadTrackdir((Trackdir)(v->state & RVSB_TRACKDIR_MASK))) return;
/* Can't overtake a vehicle that is moving faster than us. If the vehicle in front is
- * accelerating, take the maximum speed for the comparison, else the current speed. */
- int u_speed = u->GetAcceleration() > 0 ? u->GetCurrentMaxSpeed() : u->cur_speed;
+ * accelerating, take the maximum speed for the comparison, else the current speed.
+ * Original acceleration always accelerates, so always use the maximum speed. */
+ int u_speed = (_settings_game.vehicle.roadveh_acceleration_model == AM_ORIGINAL || u->GetAcceleration() > 0) ? u->GetCurrentMaxSpeed() : u->cur_speed;
if (u_speed >= v->GetCurrentMaxSpeed() &&
!(u->vehstatus & VS_STOPPED) &&
u->cur_speed != 0) {